==> haskell-config-schema-1.3.0.0-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-schema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-schema
version:              1.3.0.0
visibility:           public
id:                   config-schema-1.3.0.0-LH5zUjUPsOA9gUW4xMJJNK
key:                  config-schema-1.3.0.0-LH5zUjUPsOA9gUW4xMJJNK
license:              ISC
copyright:            Eric Mertens 2017
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-schema
synopsis:             Schema definitions for the config-value package
description:
    This package makes it possible to define schemas for use when
    loading configuration files using the config-value format.
    These schemas can be used to process a configuration file into
    a Haskell value or to automatically generate documentation for
    the file format.

category:             Language
abi:                  72bededff1c37994bf5dfe6d61f08fdc
exposed:              True
exposed-modules:
    Config.Schema Config.Schema.Docs Config.Schema.Load
    Config.Schema.Load.Error Config.Schema.Spec Config.Schema.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-schema
hs-libraries:         HSconfig-schema-1.3.0.0-LH5zUjUPsOA9gUW4xMJJNK
depends:
    base-4.17.2.1 config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH
    containers-0.6.7 free-5.2-2RtOTHKFvJpH8282U4t1Yu
    kan-extensions-5.2.7-GIWb9wDBGct24fUMlqoqO9 pretty-1.1.3.6
    semigroupoids-6.0.1-3CUWeXYcv8xJ5tqbj8MWiW text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-config-schema/html/config-schema.haddock

haddock-html:         /usr/share/doc/haskell-config-schema/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-schema-1.3.0.0-211-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-schema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-schema
version:              1.3.0.0
visibility:           public
id:                   config-schema-1.3.0.0-97y6bB04uhQ7zQYvm12jGv
key:                  config-schema-1.3.0.0-97y6bB04uhQ7zQYvm12jGv
license:              ISC
copyright:            Eric Mertens 2017
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-schema
synopsis:             Schema definitions for the config-value package
description:
    This package makes it possible to define schemas for use when
    loading configuration files using the config-value format.
    These schemas can be used to process a configuration file into
    a Haskell value or to automatically generate documentation for
    the file format.

category:             Language
abi:                  eec1f87dbefe6bc5c6a2e783078dc86a
exposed:              True
exposed-modules:
    Config.Schema Config.Schema.Docs Config.Schema.Load
    Config.Schema.Load.Error Config.Schema.Spec Config.Schema.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-schema
hs-libraries:         HSconfig-schema-1.3.0.0-97y6bB04uhQ7zQYvm12jGv
depends:
    base-4.17.2.1 config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH
    containers-0.6.7 free-5.2-8n63L5XNWv09r5UXg2kWUU
    kan-extensions-5.2.7-63vPVu2f9oT32MurC03OXE pretty-1.1.3.6
    semigroupoids-6.0.1-20Td3TsVKPT7ywapKS1MKw text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-config-schema/html/config-schema.haddock

haddock-html:         /usr/share/doc/haskell-config-schema/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
